<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" exclude-result-prefixes="fo">
  <xsl:output method="xml" version="1.0" omit-xml-declaration="no" indent="yes"/>
  <xsl:param name="versionParam" select="'1.0'"/> 

  <xsl:template match="/">
    <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
      <fo:layout-master-set>
        <fo:simple-page-master master-name="A4" page-height="29.7cm" page-width="21cm" margin-top="2cm" margin-bottom="2cm" margin-left="2cm" margin-right="2cm">
          <fo:region-body/>
          <fo:region-after />
        </fo:simple-page-master>
      </fo:layout-master-set>

      <xsl:for-each select="data-crow-objects/*">      
      <fo:page-sequence master-reference="A4">
      
        <fo:static-content flow-name="xsl-region-after">
          <fo:block text-align="right" font-size="10pt">page <fo:page-number/></fo:block>
        </fo:static-content>
        
        <fo:flow flow-name="xsl-region-body">
        
          <fo:block font-size="11pt" font-weight="bold"><xsl:value-of select="name"/></fo:block>
        
          <fo:block font-size="11pt">

            <fo:table table-layout="fixed" width="100%" border-collapse="separate" background-color="#FFFFEB" space-after="10" space-before="10">

              <fo:table-column column-width="3cm"/>
              <fo:table-column column-width="15cm" />

              <fo:table-body>
                <fo:table-row height="1cm">
                  <fo:table-cell background-color="#FFFFCC" padding-top="2" padding-left="2">
                    <fo:block font-weight="bold">Description</fo:block>
                  </fo:table-cell>
                        
                  <fo:table-cell padding-top="2" padding-left="2">
                    <fo:block><xsl:value-of select="description"/></fo:block>
                  </fo:table-cell>
                </fo:table-row>
                    
                <fo:table-row height="1cm">
                  <fo:table-cell  background-color="#FFFFCC" padding-top="2" padding-left="2">
                    <fo:block font-weight="bold">Category</fo:block>
                  </fo:table-cell>

                  <fo:table-cell padding-top="2" padding-left="2">
                    <fo:block><xsl:value-of select="category"/></fo:block>
                  </fo:table-cell>
                </fo:table-row>
                    
                <fo:table-row height="1cm">
                  <fo:table-cell  background-color="#FFFFCC" padding-top="2" padding-left="2">
                    <fo:block font-weight="bold">Email</fo:block>
                  </fo:table-cell>

                  <fo:table-cell padding-top="2" padding-left="2">
                    <fo:block><xsl:value-of select="email"/></fo:block>
                  </fo:table-cell>
                </fo:table-row>

                <fo:table-row height="1cm">
                  <fo:table-cell background-color="#FFFFCC" padding-top="2" padding-left="2">
                    <fo:block font-weight="bold">Address</fo:block>
                  </fo:table-cell>

                  <fo:table-cell padding-top="2" padding-left="2">
                    <fo:block><xsl:value-of select="address"/></fo:block>
                  </fo:table-cell>
                </fo:table-row>

                <fo:table-row height="1cm">
                  <fo:table-cell background-color="#FFFFCC" padding-top="2" padding-left="2">
                    <fo:block font-weight="bold">Phone (home)</fo:block>
                  </fo:table-cell>

                  <fo:table-cell padding-top="2" padding-left="2">
                    <fo:block><xsl:value-of select="phone-home"/></fo:block>
                  </fo:table-cell>
                </fo:table-row>

                <fo:table-row height="1cm">
                  <fo:table-cell background-color="#FFFFCC" padding-top="2" padding-left="2">
                    <fo:block font-weight="bold">Phone (work)</fo:block>
                  </fo:table-cell>

                  <fo:table-cell padding-top="2" padding-left="2">
                    <fo:block><xsl:value-of select="phone-work"/></fo:block>
                  </fo:table-cell>
                </fo:table-row>
              </fo:table-body>
            </fo:table>
          </fo:block>

          <xsl:if test="picture-front != '' or screenshot-one != '' or screenshot-two != ''">
            <fo:table table-layout="fixed" width="100%" border-collapse="separate">
              <xsl:if test="picture-front != ''"><fo:table-column column-width="33%" /></xsl:if>
              <xsl:if test="screenshot-one != ''"><fo:table-column column-width="33%" /></xsl:if>
              <xsl:if test="screenshot-two != ''"><fo:table-column column-width="33%" /></xsl:if>

              <fo:table-body>
              <fo:table-row>

              <xsl:if test="picture-front != ''">
                <fo:table-cell>
                  <fo:block>
                    <fo:external-graphic content-width="5cm" content-height="5cm" scaling="uniform">
                      <xsl:attribute name="src">url('<xsl:value-of select="picture-front" />')</xsl:attribute>
                    </fo:external-graphic> 
                  </fo:block>
                </fo:table-cell>
              </xsl:if>

              <xsl:if test="screenshot-one != ''">
                <fo:table-cell>
                  <fo:block>
                    <fo:external-graphic content-width="5cm" content-height="5cm" scaling="uniform">
                        <xsl:attribute name="src">url('<xsl:value-of select="screenshot-one" />')</xsl:attribute>
                    </fo:external-graphic>
                  </fo:block>
                </fo:table-cell>
              </xsl:if>

              <xsl:if test="screenshot-two != ''">
                <fo:table-cell>
                  <fo:block>
                    <fo:external-graphic content-width="5cm" content-height="5cm" scaling="uniform">
                        <xsl:attribute name="src">url('<xsl:value-of select="screenshot-two" />')</xsl:attribute>
                    </fo:external-graphic> 
                  </fo:block>
                </fo:table-cell>
              </xsl:if>
            </fo:table-row>

            </fo:table-body>
            </fo:table>
             
            &#x20;&#x200b;
             
          </xsl:if>
        </fo:flow>
        
      </fo:page-sequence>
    </xsl:for-each>
  </fo:root>
</xsl:template>
</xsl:stylesheet>
